@@ -1,6 +1,6 @@
    /*
 
-    $Id: kfax.cpp,v 1.50 2000/05/24 09:34:32 kulow Exp $
+    $Id: kfax.cpp,v 1.53 2000/10/09 21:10:11 faure Exp $
 
     Copyright (C) 1997 Bernd Johannes Wuebben
                        wuebben@math.cornell.edu
@@ -21,6 +21,11 @@
 
     */
 
+#ifdef KDE_USE_FINAL
+/* NewImage() in viewfax.cpp needs to fiddle with the Display structure */
+#define XLIB_ILLEGAL_ACCESS
+#endif
+
 #include <stdlib.h>
 #include <signal.h>
 #include <time.h>
@@ -188,9 +193,8 @@ bool MyApp::x11EventFilter( XEvent * ev){
 
 
 TopLevel::TopLevel (QWidget *, const char *name)
-    : KTMainWindow ( name)
+    : KMainWindow (0, name)
 {
-
   setMinimumSize (100, 100);
 
   file_dialog = NULL;
@@ -201,7 +205,6 @@ TopLevel::TopLevel (QWidget *, const char *name)
 
   connect(kapp,SIGNAL(kdisplayPaletteChanged()),this,SLOT(set_colors()));
 
-
   setupMenuBar();
   setupToolBar();
   setupStatusBar();
@@ -226,19 +229,9 @@ TopLevel::TopLevel (QWidget *, const char *name)
   hsb->hide();
 
 
-  setView(faxqtwin,TRUE);
+  setCentralWidget(faxqtwin);
   set_colors();
 
-  if ( hide_toolbar )	
-    options->changeItem( i18n("Show &Tool Bar"), toolID );
-  else
-    options->changeItem(i18n( "Hide &Tool Bar"), toolID );
-
-  if ( hide_statusbar )
-    options->changeItem(i18n( "Show &Status Bar"), statusID );
-  else
-    options->changeItem( i18n("Hide &Status Bar"), statusID );
-
   setCaption(i18n("KFax"));
 
   setAcceptDrops(true);
@@ -282,7 +275,7 @@ void TopLevel::setupEditWidget(){
 
 void TopLevel::resizeEvent(QResizeEvent *e){
 
-  KTMainWindow::resizeEvent(e);
+  KMainWindow::resizeEvent(e);
 
   if(!faxqtwin || !display_is_setup)
     return;
@@ -435,49 +428,41 @@ void TopLevel::setupMenuBar(){
   menubar->insertItem (i18n("&Options"), options);
   menubar->insertSeparator(-1);
   menubar->insertItem (i18n("&Help"), help);
-
-  setMenu(menubar);
-
-
 }
 
 
-void TopLevel::setupToolBar(){
+void TopLevel::setupToolBar()
+{
+    toolBar()->insertButton(BarIcon("back"), ID_PREV, TRUE, i18n("Go back"));
+    toolBar()->insertButton(BarIcon("forward"), ID_NEXT, TRUE, i18n("Go forward"));
 
-    toolbar = new KToolBar( this );
+    toolBar()->insertSeparator();
 
-    toolbar->insertButton(BarIcon("back"), ID_PREV, TRUE, i18n("Go back"));
-    toolbar->insertButton(BarIcon("forward"), ID_NEXT, TRUE, i18n("Go forward"));
+    toolBar()->insertButton(BarIcon("start"), ID_START, TRUE, i18n("Go to start"));
+    toolBar()->insertButton(BarIcon("finish"), ID_END, TRUE, i18n("Go to end"));
 
-    toolbar->insertSeparator();
+    toolBar()->insertSeparator();
 
-    toolbar->insertButton(BarIcon("start"), ID_START, TRUE, i18n("Go to start"));
-    toolbar->insertButton(BarIcon("finish"), ID_END, TRUE, i18n("Go to end"));
+    toolBar()->insertButton(BarIcon("viewmag+"), ID_ZOOM_IN, TRUE,i18n( "Zoom in"));
+    toolBar()->insertButton(BarIcon("viewmag-"), ID_ZOOM_OUT, TRUE, i18n("Zoom out"));
 
-    toolbar->insertSeparator();
+    toolBar()->insertSeparator();
 
-    toolbar->insertButton(BarIcon("viewmag+"), ID_ZOOM_IN, TRUE,i18n( "Zoom in"));
-    toolbar->insertButton(BarIcon("viewmag-"), ID_ZOOM_OUT, TRUE, i18n("Zoom out"));
-
-    toolbar->insertSeparator();
-
-    toolbar->insertButton(BarIcon("fileprint"), ID_PRINT, TRUE, i18n("Print document"));
+    toolBar()->insertButton(BarIcon("fileprint"), ID_PRINT, TRUE, i18n("Print document"));
 
     /*
-	toolbar->insertButton(BarIcon("tick"), ID_MARK, TRUE, "Mark this page");
+	toolBar()->insertButton(BarIcon("tick"), ID_MARK, TRUE, "Mark this page");
     */
-    toolbar->insertSeparator();
+    toolBar()->insertSeparator();
 
-    toolbar->insertButton(BarIcon("page"), ID_PAGE, TRUE, i18n("Go to page ..."));
+    toolBar()->insertButton(BarIcon("page"), ID_PAGE, TRUE, i18n("Go to page ..."));
 
-  toolbar1 = addToolBar( toolbar );
+    toolBar()->setBarPos( KToolBar::Top );
 	
-  toolbar->setBarPos( KToolBar::Top );
-	
-  connect(toolbar, SIGNAL( clicked( int ) ), this,
+    connect(toolBar(), SIGNAL( clicked( int ) ), this,
           SLOT( toolbarClicked( int ) ) );
 
-  connect(toolbar, SIGNAL( moved( BarPosition ) ), this,
+    connect(toolBar(), SIGNAL( moved( BarPosition ) ), this,
           SLOT( toolbarMoved(BarPosition ) ) );
 }
 
@@ -520,31 +505,26 @@ void TopLevel::toolbarClicked( int item ){
 }
 
 void TopLevel::setupStatusBar(){
+    //    statusBar()->insertFixedItem("Mem: 000000000", ID_LINE_COLUMN);
+    statusBar()->insertFixedItem(i18n("w: 00000 h: 00000"), ID_INS_OVR);
+    statusBar()->insertFixedItem(i18n("Res: XXXXX"), ID_GENERAL);
+    statusBar()->insertFixedItem(i18n("Type: XXXXXXX"), ID_TYPE);
+    statusBar()->insertFixedItem(i18n("P:XXXofXXX"), ID_PAGE_NO);
+    statusBar()->insertItem("",ID_FNAME, 1);
 
-    statusbar = new KStatusBar( this );
-    //    statusbar->insertItem("Mem: 000000000", ID_LINE_COLUMN);
-    statusbar->insertItem(i18n("w: 00000 h: 00000"), ID_INS_OVR);
-    statusbar->insertItem(i18n("Res: XXXXX"), ID_GENERAL);
-    statusbar->insertItem(i18n("Type: XXXXXXX"), ID_TYPE);
-    statusbar->insertItem(i18n("P:XXXofXXX"), ID_PAGE_NO);
-    statusbar->insertItem("",ID_FNAME);
+    //    statusBar()->changeItem("", ID_LINE_COLUMN);
+    statusBar()->changeItem("", ID_INS_OVR);
+    statusBar()->changeItem("", ID_GENERAL);
+    statusBar()->changeItem("", ID_TYPE);
+    statusBar()->changeItem("", ID_PAGE_NO);
+    statusBar()->changeItem("",ID_FNAME);
 
-    //    statusbar->changeItem("", ID_LINE_COLUMN);
-    statusbar->changeItem("", ID_INS_OVR);
-    statusbar->changeItem("", ID_GENERAL);
-    statusbar->changeItem("", ID_TYPE);
-    statusbar->changeItem("", ID_PAGE_NO);
-    statusbar->changeItem("",ID_FNAME);
+    //statusBar()->setInsertOrder(KStatusBar::RightToLeft);
 
-    //statusbar->setInsertOrder(KStatusBar::RightToLeft);
-
-    //    statusbar->setAlignment(ID_INS_OVR,AlignCenter);
-
-    //    statusbar->setInsertOrder(KStatusBar::LeftToRight);
-    //    statusbar->setBorderWidth(1);
-
-    setStatusBar( statusbar );
+    //    statusBar()->setAlignment(ID_INS_OVR,AlignCenter);
 
+    //    statusBar()->setInsertOrder(KStatusBar::LeftToRight);
+    //    statusBar()->setBorderWidth(1);
 }
 
 
@@ -734,7 +714,7 @@ QFileDialog* TopLevel::getFileDialog(const QString& captiontext){
 void TopLevel::setGeneralStatusField(QString text){
 
     statusbar_timer->stop();
-    statusbar->changeItem(text,ID_FNAME);
+    statusBar()->changeItem(text,ID_FNAME);
     statusbar_timer->start(10000,TRUE); // single shot
 
 }
@@ -765,18 +745,15 @@ void TopLevel::helpshort(){
 void TopLevel::toggleStatusBar(){
 
   if(hide_statusbar) {
-
     hide_statusbar=FALSE;
-    enableStatusBar( KStatusBar::Show );
+    statusBar()->show();
     options->changeItem(i18n("Hide &Status Bar"), statusID);
 
   }
   else {
-
     hide_statusbar=TRUE;
-    enableStatusBar( KStatusBar::Hide );
+    statusBar()->hide();
     options->changeItem(i18n("Show &Status Bar"), statusID);
-
   }
   resizeView();
 
@@ -790,16 +767,14 @@ void TopLevel::dummy(){
 void TopLevel::toggleToolBar(){
 
   if(hide_toolbar) {
-
     hide_toolbar=FALSE;
-    enableToolBar( KToolBar::Show, toolbar1 );
+    toolBar()->show();
     options->changeItem(i18n("Hide &Tool Bar"), toolID);
-
   }
   else {
 
     hide_toolbar=TRUE;
-    enableToolBar( KToolBar::Hide, toolbar1 );
+    toolBar()->hide();
     options->changeItem(i18n("Show &Tool Bar"), toolID);
 
   }
@@ -821,7 +796,7 @@ void TopLevel::closeEvent( QCloseEvent *e ){
 void TopLevel::setStatusBarMemField(int /*mem*/){
 
     //    QString memstr = i18n("Mem: %1").arg(mem);
-    //    statusbar->changeItem(memstr, ID_LINE_COLUMN);
+    //    statusBar()->changeItem(memstr, ID_LINE_COLUMN);
 
 }
 
@@ -1166,10 +1141,10 @@ void TopLevel::timer_slot(){
 
   if(thispage){
     if(thispage->name)
-      statusbar->changeItem(thispage->name,ID_FNAME);
+      statusBar()->changeItem(thispage->name,ID_FNAME);
   }
   else
-      statusbar->changeItem("",ID_FNAME);
+      statusBar()->changeItem("",ID_FNAME);
 
 }
 
@@ -1193,141 +1168,62 @@ void TopLevel::set_colors(){
 }
 
 
-void TopLevel::readSettings(){
-
-	// let's set the defaults
-
-	editor_width = 550;
-	editor_height = 400;
-	hide_statusbar = FALSE;
-	hide_toolbar = FALSE;
-	
-	// fas display options
-
-	fop.width = 1728;
-	fop.height = 2339;
-	fop.resauto = 1;
-	fop.geomauto = 1;
-	fop.fine = 1;
-	fop.landscape = 0;
-	fop.flip = 0;
-	fop.invert =0;
-	fop.lsbfirst = 0;
-	fop.raw = 3;  // raw faxes are g3 by default -- 2 stands for g32d and 4 for g4
-	
-	current_directory = QDir::currentDirPath();
-
-
-	QString str;
-	
-	config = kapp->config();
+void TopLevel::readSettings()
+{
+	config = KGlobal::config();
 
 	///////////////////////////////////////////////////
 	config->setGroup("General Options");
 
+	current_directory = config->readEntry("DefaultPath", QDir::currentDirPath());
+	editor_width = config->readNumEntry("Width", 550);
+	editor_height = config->readNumEntry("Height", 400);
 
-	str = config->readEntry("DefaultPath");
-	if ( !str.isEmpty() ){
-	  current_directory = str;
-	}
+        // Inverse logic. Default is "show statusbar".
+        hide_statusbar = config->readBoolEntry( "StatusBar", true ); 
+        toggleStatusBar();
 
-	str = config->readEntry("Width");
-		if ( !str.isNull() )
-		  editor_width = str.toInt();
+        // Inverse logic. Default is "show toolbar".
+        hide_toolbar = config->readBoolEntry("ToolBar", true);
+        toggleToolBar(); 
 
-	str = config->readEntry("Height");
-		if ( !str.isNull() )
-		  editor_height = str.toInt();
-
-
-	str = config->readEntry( "StatusBar" );
-	if ( !str.isNull() && str.find( "off" ) == 0 ) {
-		hide_statusbar = TRUE;
-		enableStatusBar( KStatusBar::Hide );
-
-	} else
-	  {
-		hide_statusbar = FALSE;
-		enableStatusBar( KStatusBar::Show );
-	  }
-
-	str = config->readEntry( "ToolBar" );
-
-	if ( !str.isNull() && str.find( "off" ) == 0 ) {
-		hide_toolbar = TRUE;
-		enableToolBar( KToolBar::Hide, toolbar1 );
-	} else{
-		hide_toolbar = FALSE;
-		enableToolBar( KToolBar::Show, toolbar1 );
-
-	}
-
-	str = config->readEntry( "Toolbar position" );
+	QString str = config->readEntry( "Toolbar position" );
 	if ( !str.isNull() ) {
 		if( str == "Left" ) {
-			toolbar->setBarPos( KToolBar::Left );
+			toolBar()->setBarPos( KToolBar::Left );
 		} else if( str == "Right" ) {
-			toolbar->setBarPos( KToolBar::Right );
+			toolBar()->setBarPos( KToolBar::Right );
 		} else if( str == "Bottom" ) {
-			toolbar->setBarPos( KToolBar::Bottom );
+			toolBar()->setBarPos( KToolBar::Bottom );
 		} else
-			toolbar->setBarPos( KToolBar::Top );
+			toolBar()->setBarPos( KToolBar::Top );
 	}			
 
 	///////////////////////////////////////////////////
 	config->setGroup("Fax Options");
 
-	str = config->readEntry("width");
-		if ( !str.isNull() )
-		  fop.width = str.toInt();
+	fop.width = config->readNumEntry("width", 1728);
+	fop.resauto = config->readNumEntry("resauto", 1);
+	fop.geomauto = config->readNumEntry("geomauto", 1);
+	fop.height = config->readNumEntry("height", 2339);
+	fop.fine = config->readNumEntry("resolution", 1);
+	fop.flip = config->readNumEntry("flip", 0);
+	fop.invert = config->readNumEntry("invert", 0);
+	fop.lsbfirst = config->readNumEntry("lsb", 0);
+	fop.raw = config->readNumEntry("raw", 3);
 
-	str = config->readEntry("resauto");
-		if ( !str.isNull() )
-		  fop.resauto = str.toInt();
-
-	str = config->readEntry("geomauto");
-		if ( !str.isNull() )
-		  fop.geomauto = str.toInt();
-
-	str = config->readEntry("height");
-		if ( !str.isNull() )
-		  fop.height = str.toInt();
-
-	str = config->readEntry("resolution");
-		if ( !str.isNull() )
-		  fop.fine = str.toInt();
-
-	str = config->readEntry("flip");
-		if ( !str.isNull() )
-		  fop.flip = str.toInt();
-
-	str = config->readEntry("invert");
-		if ( !str.isNull() )
-		  fop.invert = str.toInt();
-
-	str = config->readEntry("lsb");
-		if ( !str.isNull() )
-		  fop.lsbfirst = str.toInt();
-
-	str = config->readEntry("raw");
-		if ( !str.isNull() )
-		  fop.raw = str.toInt();
-
-		
-	 setFaxDefaults();
+	setFaxDefaults();
 	///////////////////////////////////////////////////
 
 	config->setGroup("Printing");
 
-	pi.cmd = config->readEntry("PrintCommand","lpr");
-	pi.file = config->readEntry("PrintFile","");
-	pi.lpr = config->readNumEntry("print",1);
-	pi.scale = config->readNumEntry("scale",0);
-	pi.margins = config->readNumEntry("margins",0);
-	str = config->readEntry("xmargin","0.0");
-	pi.xmargin = str.toDouble();
-	str = config->readEntry("ymargin","0.0");
-	pi.ymargin = str.toDouble();
+	pi.cmd = config->readEntry("PrintCommand", "lpr");
+	pi.file = config->readEntry("PrintFile");
+	pi.lpr = config->readNumEntry("print", 1);
+	pi.scale = config->readNumEntry("scale", 0);
+	pi.margins = config->readNumEntry("margins", 0);
+	pi.xmargin = config->readNumEntry("xmargin", 0.0);
+	pi.ymargin = config->readNumEntry("ymargin", 0.0);
 	pi.pagesize = config->readEntry("PageSize",US_LETTER);
 }
 
@@ -1341,27 +1237,18 @@ void TopLevel::writeSettings(){
 	
 	config->setGroup("General Options");
 
-        config->writeEntry("DefaultPath",current_directory);
-
-	QString widthstring;
-	widthstring.setNum(this->width() );
-	config->writeEntry("Width",  widthstring);
-
-	QString heightstring;
-	heightstring.setNum(this->height() );
-
-	config->writeEntry("Height",  heightstring);
-
-	config->writeEntry( "StatusBar", hide_statusbar ? "off" : "on" );
-	config->writeEntry( "ToolBar", hide_toolbar ? "off" : "on" );
+        config->writeEntry("DefaultPath", current_directory);
+	config->writeEntry("Width", this->width());
+	config->writeEntry("Height", this->height());
+	config->writeEntry("StatusBar", !hide_statusbar);
+	config->writeEntry("ToolBar", !hide_toolbar);
 
 	QString string;
-	string="";
-	if ( toolbar->barPos() == KToolBar::Left )
+	if ( toolBar()->barPos() == KToolBar::Left )
 		string = "Left";
-	else if ( toolbar->barPos() == KToolBar::Right )
+	else if ( toolBar()->barPos() == KToolBar::Right )
 		string = "Right";
-	else if ( toolbar->barPos() == KToolBar::Bottom )
+	else if ( toolBar()->barPos() == KToolBar::Bottom )
 		string = "Bottom";
 	else
 		string = "Top";
@@ -1392,10 +1279,8 @@ void TopLevel::writeSettings(){
 	config->writeEntry("scale",pi.scale);
 	config->writeEntry("PageSize",pi.pagesize);
 	config->writeEntry("margins",pi.margins);
-	string.sprintf("%.2f",pi.xmargin);
-	config->writeEntry("xmargin",string);
-	string.sprintf("%.2f",pi.ymargin);
-	config->writeEntry("ymargin",string);
+	config->writeEntry("xmargin", pi.xmargin);
+	config->writeEntry("ymargin", pi.ymargin);
 	config->sync();	
 }
 
@@ -1495,7 +1380,6 @@ void TopLevel::zoomin(){
   int i;
 
   if (Image == NULL) {
-
     for (i = oz; i && (Images[i] == NULL); i--)
       ;
     for (; i != oz; i++){
@@ -1507,8 +1391,6 @@ void TopLevel::zoomin(){
 	break;
       }
     }
-
-
   }
 
   PaneWidth = Image->width;
@@ -1518,12 +1400,10 @@ void TopLevel::zoomin(){
   putImage();
 
   uiUpdate();
-
 }
 
-
-void TopLevel::zoomout(){
-
+void TopLevel::zoomout()
+{
   if(!thispage || !Image || !faxqtwin || !display_is_setup)
     return;
 
@@ -1558,12 +1438,10 @@ void TopLevel::zoomout(){
   putImage();
 
   uiUpdate();
-
 }
 
-void TopLevel::handle_X_event(XEvent Event){
-
-
+void TopLevel::handle_X_event(XEvent Event)
+{
   if(!thispage || !Image || !faxqtwin || !display_is_setup)
     return;
 
@@ -1573,11 +1451,8 @@ void TopLevel::handle_X_event(XEvent Event){
   if(!faxqtwin || !display_is_setup)
     return;
 
-
   bool putimage = false; // Do we actually have to write the image to the scree?
 
-
-
   do {
     switch(Event.type) {
     case MappingNotify:
@@ -1778,15 +1653,14 @@ void TopLevel::handle_X_event(XEvent Event){
 
   } while (XCheckWindowEvent(qtdisplay, Win, KeyPressMask|ButtonPressMask, &Event));
 
-  if(putimage == TRUE){
+  if(putimage == TRUE) {
     Refresh = Resize = 1;
     putImage();
   }
-
 }
 
-void TopLevel::rotatePage(){
-
+void TopLevel::rotatePage()
+{
   if(!thispage || !Image || !faxqtwin || !display_is_setup)
     return;
 
@@ -1831,15 +1705,13 @@ void TopLevel::rotatePage(){
   //	XDefineCursor(qtdisplay, Win, ReadyCursor);
 
   putImage();
-
 }
 
-void TopLevel::flipPage(){
-
+void TopLevel::flipPage()
+{
   if(!thispage || !Image || !faxqtwin || !display_is_setup)
     return;
 
-
   XImage *newflipimage = NULL;
 
   XDefineCursor(qtdisplay, Win, WorkCursor);
@@ -1878,12 +1750,8 @@ void TopLevel::flipPage(){
 
   Refresh = Resize = 1;
   putImage();
-
 }
 
-
-
-
 void TopLevel::mirrorPage(){
 
   if(!thispage || !Image || !faxqtwin || !display_is_setup)
@@ -2212,47 +2080,47 @@ void TopLevel::uiUpdate(){
 
   if(!thispage){
 
-    toolbar->setItemEnabled( ID_ZOOM_IN, FALSE );
-    toolbar->setItemEnabled( ID_ZOOM_OUT, FALSE );
-    toolbar->setItemEnabled( ID_PREV, FALSE );
-    toolbar->setItemEnabled( ID_START, FALSE );
-    toolbar->setItemEnabled( ID_NEXT, FALSE );
-    toolbar->setItemEnabled( ID_END, FALSE );
-    toolbar->setItemEnabled( ID_PRINT,FALSE);
+    toolBar()->setItemEnabled( ID_ZOOM_IN, FALSE );
+    toolBar()->setItemEnabled( ID_ZOOM_OUT, FALSE );
+    toolBar()->setItemEnabled( ID_PREV, FALSE );
+    toolBar()->setItemEnabled( ID_START, FALSE );
+    toolBar()->setItemEnabled( ID_NEXT, FALSE );
+    toolBar()->setItemEnabled( ID_END, FALSE );
+    toolBar()->setItemEnabled( ID_PRINT,FALSE);
 
-    statusbar->changeItem("", ID_INS_OVR);
-    statusbar->changeItem("", ID_GENERAL);
-    statusbar->changeItem("", ID_PAGE_NO);
-    statusbar->changeItem("",ID_FNAME);
-    statusbar->changeItem("",ID_TYPE);
+    statusBar()->changeItem("", ID_INS_OVR);
+    statusBar()->changeItem("", ID_GENERAL);
+    statusBar()->changeItem("", ID_PAGE_NO);
+    statusBar()->changeItem("",ID_FNAME);
+    statusBar()->changeItem("",ID_TYPE);
 
     return;
   }
 
   if(  thispage->next != NULL){
 
-    toolbar->setItemEnabled( ID_NEXT, TRUE );
-    toolbar->setItemEnabled( ID_END, TRUE );
+    toolBar()->setItemEnabled( ID_NEXT, TRUE );
+    toolBar()->setItemEnabled( ID_END, TRUE );
 
   }
   else{
 
-    toolbar->setItemEnabled( ID_NEXT, FALSE );
-    toolbar->setItemEnabled( ID_END, FALSE );
+    toolBar()->setItemEnabled( ID_NEXT, FALSE );
+    toolBar()->setItemEnabled( ID_END, FALSE );
 
   }
 
 
   if(  thispage->prev != NULL){
 
-    toolbar->setItemEnabled( ID_PREV, TRUE );
-    toolbar->setItemEnabled( ID_START, TRUE );
+    toolBar()->setItemEnabled( ID_PREV, TRUE );
+    toolBar()->setItemEnabled( ID_START, TRUE );
 
   }
   else{
 
-    toolbar->setItemEnabled( ID_PREV, FALSE );
-    toolbar->setItemEnabled( ID_START, FALSE );
+    toolBar()->setItemEnabled( ID_PREV, FALSE );
+    toolBar()->setItemEnabled( ID_START, FALSE );
 
   }
 
@@ -2272,21 +2140,20 @@ void TopLevel::uiUpdate(){
 
     QString pagestr = i18n("P.%1 of %2").arg(currentpage).arg(pages);
 
-    statusbar->changeItem(pagestr, ID_PAGE_NO);
+    statusBar()->changeItem(pagestr, ID_PAGE_NO);
 
-    toolbar->setItemEnabled( ID_ZOOM_IN, TRUE );
-    toolbar->setItemEnabled( ID_ZOOM_OUT, TRUE );
-    toolbar->setItemEnabled( ID_PRINT,TRUE);
+    toolBar()->setItemEnabled( ID_ZOOM_IN, TRUE );
+    toolBar()->setItemEnabled( ID_ZOOM_OUT, TRUE );
+    toolBar()->setItemEnabled( ID_PRINT,TRUE);
     if(Image){
-
-    QString wh = i18n("W: %1 H: %2").arg(Image->width).arg(Image->height);
-    statusbar->changeItem(wh, ID_INS_OVR);
+      QString wh = i18n("W: %1 H: %2").arg(Image->width).arg(Image->height);
+      statusBar()->changeItem(wh, ID_INS_OVR);
     }
 
     QString resolution = i18n("Res: %1").arg(thispage->vres?i18n("Fine"):i18n("Normal"));
-    statusbar->changeItem(resolution, ID_GENERAL);
+    statusBar()->changeItem(resolution, ID_GENERAL);
 
-    statusbar->changeItem(thispage->name,ID_FNAME);
+    statusBar()->changeItem(thispage->name,ID_FNAME);
 
     QString typestring;
 
@@ -2306,9 +2173,9 @@ void TopLevel::uiUpdate(){
     if ( thispage->expander == g4expand )
       typestring += "G4";
 
-    statusbar->changeItem(typestring,ID_TYPE);
+    statusBar()->changeItem(typestring,ID_TYPE);
     //    QString memstr = i18n("Mem: %1").arg(Memused);
-    //    statusbar->changeItem(memstr, ID_LINE_COLUMN);
+    //    statusBar()->changeItem(memstr, ID_LINE_COLUMN);
 
   }
 
@@ -2604,8 +2471,8 @@ void parse(char* buf, char** args){
 
 }
 
-int copyfile(const char* toname,char* fromname){
-
+int copyfile(const char* toname,char* fromname)
+{
   char buffer[4*1028];
   int count = 0;
   int count2;
@@ -2640,6 +2507,6 @@ int copyfile(const char* toname,char* fromname){
   }
   fclose(fromfile);
   fclose(tofile);
-  return 1;
 
+  return 1;
 }
