@@ -1,7 +1,7 @@
 /*
 * typolayout.cpp -- Implementation of class KTypoLayout.
 * Author:	Sirtaj Singh Kang
-* Version:	$Id: typolayout.cpp,v 1.6 2000/03/03 22:38:00 waba Exp $
+* Version:	$Id: typolayout.cpp,v 1.8 2000/08/06 10:25:11 bieker Exp $
 * Generated:	Tue May  5 01:12:37 EST 1998
 */
 
@@ -29,7 +29,7 @@ KTypoLayout::KTypoLayout( QWidget *parent )
 	_group = 0;
 }
 
-QLabel *KTypoLayout::newLabel( const char *text, int x, int y, 
+QLabel *KTypoLayout::newLabel( const QString & text, int x, int y, 
 			int xspan, int yspan )
 {
 	QLabel *w = new QLabel( text, _parent );
@@ -40,7 +40,7 @@ QLabel *KTypoLayout::newLabel( const char *text, int x, int y,
 
 }
 
-QPushButton *KTypoLayout::newButton( const char *text, int x, int y, 
+QPushButton *KTypoLayout::newButton( const QString & text, int x, int y, 
 			int xspan, int yspan )
 {
 	QPushButton *w = new QPushButton( text, _parent );
@@ -53,7 +53,7 @@ QPushButton *KTypoLayout::newButton( const char *text, int x, int y,
 	return w;
 }
 
-QRadioButton *KTypoLayout::newRadioButton( const char *text, int x, int y, 
+QRadioButton *KTypoLayout::newRadioButton( const QString & text, int x, int y, 
 			int xspan, int yspan )
 {
 	QRadioButton *w = new QRadioButton ( text, _parent );
@@ -66,7 +66,7 @@ QRadioButton *KTypoLayout::newRadioButton( const char *text, int x, int y,
 	return w;
 }
 
-QLineEdit *KTypoLayout::newLineEdit( const char *text, int x, int y, 
+QLineEdit *KTypoLayout::newLineEdit( const QString & text, int x, int y, 
 			int xspan, int yspan )
 {
 	QLineEdit * w = new QLineEdit( _parent );
@@ -82,7 +82,7 @@ QLineEdit *KTypoLayout::newLineEdit( const char *text, int x, int y,
 }
 
 
-QMultiLineEdit *KTypoLayout::newMultiLineEdit( const char *text, 
+QMultiLineEdit *KTypoLayout::newMultiLineEdit( const QString & text, 
 		int x, int y, int xspan, int yspan )
 {
 	QMultiLineEdit * w = new QMultiLineEdit( _parent );
@@ -93,7 +93,7 @@ QMultiLineEdit *KTypoLayout::newMultiLineEdit( const char *text,
 	return w;
 }
 
-QCheckBox *KTypoLayout::newCheckBox( const char *text, int x, int y, 
+QCheckBox *KTypoLayout::newCheckBox( const QString & text, int x, int y, 
 			int xspan, int yspan )
 {
 	QCheckBox *w = new QCheckBox ( text, _parent );
@@ -127,7 +127,7 @@ KTypoLayout *KTypoLayout::newSubLayout( int x, int y, int xspan, int yspan )
 }
 
 
-KTypoLayout *KTypoLayout::newSubGroup( const char *title, int x, int y, 
+KTypoLayout *KTypoLayout::newSubGroup( const QString & title, int x, int y, 
 	int xspan, int yspan )
 {
 	QGroupBox *holder = new QGroupBox( title, _parent );
@@ -154,3 +154,4 @@ void KTypoLayout::endGroup()
 {
 	_group = 0;
 }
+#include "typolayout.moc"
