@@ -20,6 +20,7 @@
 #include <kstddirs.h>
 #include <kconfig.h>
 
+#include <math.h>
 
 #include "marklist.h"
 #include "scrollbox.h"
@@ -30,7 +31,7 @@
 
 extern "C"
 {
-  void *init_libkviewpart()
+  void *init_libkviewerpart()
   {
     return new KViewPartFactory;
   }
@@ -54,12 +55,12 @@ KViewPartFactory::~KViewPartFactory()
 }
 
 
-QObject *KViewPartFactory::create(QObject *parent, const char *name , const char*, const QStringList &args)
+KParts::Part *KViewPartFactory::createPart( QWidget *parentWidget, const char *widgetName, QObject *parent, const char *name, const char *classname, const QStringList &args )
 {
   QString partname = "";
   if (args.count() >= 1)
     partname = args[0];
-  QObject *obj = new KViewPart(partname, (QWidget *)parent, name);
+  KParts::Part *obj = new KViewPart(partname, parentWidget, widgetName, parent, name);
   emit objectCreated(obj);
   return obj;
 }
@@ -68,12 +69,12 @@ QObject *KViewPartFactory::create(QObject *parent, const char *name , const char
 KInstance *KViewPartFactory::instance()
 {
   if (!s_instance)
-    s_instance = new KInstance("kviewpart");
+    s_instance = new KInstance("kviewerpart");
   return s_instance;
 }
 
 
-class PaperSize 
+class PaperSize
 {
 public:
 
@@ -85,13 +86,13 @@ public:
 };
 
 
-KViewPart::KViewPart(QString partname, QWidget *parent, const char *name)
+KViewPart::KViewPart(QString partname, QWidget *parentWidget, const char *widgetName, QObject *parent, const char *name)
   : KParts::ReadOnlyPart(parent, name), _partname(partname), _numberOfPages(0),
   _currentPage(0), _zoom(1.0)
 {
   setInstance(KViewPartFactory::instance());
 
-  mainWidget = new QWidget(parent);
+  mainWidget = new QWidget(parentWidget, widgetName);
   mainWidget->setFocusPolicy(QWidget::StrongFocus);
   setWidget(mainWidget);
 
@@ -115,10 +116,10 @@ KViewPart::KViewPart(QString partname, QWidget *parent, const char *name)
   // create the displaying part
 
   // Try to load
-  KLibFactory *factory = KLibLoader::self()->factory(QString("libk%1").arg(_partname));
+  KLibFactory *factory = KLibLoader::self()->factory(QString("libk%1").arg(_partname).utf8());
   if (factory)
   {
-    multiPage = (KMultiPage*) factory->create(mainWidget, QString("k%1").arg(_partname), "KPart");
+    multiPage = (KMultiPage*) factory->create(mainWidget, QString("k%1").arg(_partname).utf8(), "KPart");
   }
   else
     {
@@ -131,6 +132,7 @@ KViewPart::KViewPart(QString partname, QWidget *parent, const char *name)
 
   // connect to the multi page view
   connect(multiPage, SIGNAL(numberOfPages(int)), this, SLOT(numberOfPages(int)));
+  connect(multiPage, SIGNAL(pageInfo(int, int)), this, SLOT(pageInfo(int, int)) );
   connect(multiPage->scrollView(), SIGNAL(contentsMoving(int,int)),
 	  this, SLOT(contentsMoving(int,int)));
   multiPage->scrollView()->installEventFilter(this);
@@ -144,9 +146,10 @@ KViewPart::KViewPart(QString partname, QWidget *parent, const char *name)
   connect( multiPage, SIGNAL( previewChanged(bool)), this, SLOT(updatePreview(bool)));
 
 
+
   // settings menu
-  showmarklist = new KToggleAction ("Show &Page List", 0, this, SLOT(slotShowMarkList()), actionCollection(), "show_page_list");
-  showPreview = new KToggleAction ("Show P&review", 0, this, SLOT(slotPreview()), actionCollection(), "show_preview");
+  showmarklist = new KToggleAction (i18n("Show &Page List"), 0, this, SLOT(slotShowMarkList()), actionCollection(), "show_page_list");
+  showPreview = new KToggleAction (i18n("Show P&review"), 0, this, SLOT(slotPreview()), actionCollection(), "show_preview");
   watchAct = new KToggleAction(i18n("&Watch file"), 0, 0, 0, actionCollection(), "watch_file");
 
 
@@ -154,11 +157,11 @@ KViewPart::KViewPart(QString partname, QWidget *parent, const char *name)
   QStringList orientations;
   orientations.append(i18n("Portrait"));
   orientations.append(i18n("Landscape"));
-  orientation = new KSelectAction ("&Orientation", 0, 0, 0, actionCollection(), "view_orientation");
+  orientation = new KSelectAction (i18n("&Orientation"), 0, 0, 0, actionCollection(), "view_orientation");
   connect (orientation, SIGNAL(activated (int)), this, SLOT(slotOrientation(int)));
   orientation->setItems(orientations);
 
-  media = new KSelectAction ("Paper &Size", 0, 0, 0, actionCollection(), "view_media");
+  media = new KSelectAction (i18n("Paper &Size"), 0, 0, 0, actionCollection(), "view_media");
   connect (media, SIGNAL(activated(int)), this, SLOT(slotMedia(int)));
   fillPaperSizes();
 
@@ -228,7 +231,7 @@ KViewPart::KViewPart(QString partname, QWidget *parent, const char *name)
   accel->connectItem("Scroll Left Page", this, SLOT(scrollLeftPage()));
   accel->connectItem("Scroll Right Page", this, SLOT(scrollRightPage()));
 
-  setXMLFile("kviewpart.rc");
+  setXMLFile("kviewerpart.rc");
 
 
   connect(&watch, SIGNAL(dirty(const QString&)), this, SLOT(fileChanged(const QString&)));
@@ -243,7 +246,7 @@ KViewPart::KViewPart(QString partname, QWidget *parent, const char *name)
 
   numberOfPages(0);
   checkActions();
-  
+
   // allow parts to have a GUI, too :-)
   // (will be merged automatically)
   insertChildClient( multiPage );
@@ -311,7 +314,7 @@ void KViewPart::setPaperSize(double w, double h)
 
   // forward
   multiPage->setPaperSize(w, h);
-  
+
   updateScrollBox();
 }
 
@@ -347,23 +350,27 @@ bool KViewPart::openFile()
 }
 
 bool KViewPart::openURL(const KURL &url)
-{  
+{
+  // This will download the file, if necessary and call
+  // KViewPart::openFile() which sete the file watching mechanism off.
   KParts::ReadOnlyPart::openURL(url);
 
-  bool r = multiPage->openURL(url);
+  // Now call the openURL-method of the multipage and give it a URL
+  // pointing to the downloaded file.
+  KURL tmpFileURL;
+  tmpFileURL.setPath(m_file);
+  bool r = multiPage->openURL(tmpFileURL);
 
   updateScrollBox();
   checkActions();
   markList->select(0);
 
-  if (r)
-    {
-      // start viewing horizontally centered
-      QScrollView *sv = multiPage->scrollView();
-      if (sv)
-	sv->center(sv->contentsWidth()/2, 0);
-    }  
-
+  if (r) {
+    // start viewing horizontally centered
+    QScrollView *sv = multiPage->scrollView();
+    if (sv)
+      sv->center(sv->contentsWidth()/2, 0);
+  }
   return r;
 }
 
@@ -409,7 +416,7 @@ void KViewPart::slotOrientation(int id)
 void KViewPart::slotMedia(int id)
 {
   double w=0.0, h=0.0;
-  
+
   switch (id)
     {
     case 0:
@@ -460,11 +467,36 @@ void KViewPart::numberOfPages(int nr)
     }
 
   for (int i=0; i<nr; i++)
-    markList->insertItem(QString("%1").arg(i), i);
+    markList->insertItem(QString("%1").arg(i+1), i);
 
   setPage(0);
 }
 
+void KViewPart::pageInfo(int numpages, int currentpage)
+{
+  _numberOfPages = numpages;
+
+  markList->clear();
+
+  if (numpages == 0) {
+    // clear scroll box
+    scrollBox->setPageSize(QSize(0,0));
+    scrollBox->setViewSize(QSize(0,0));
+    
+    _currentPage = 0;
+
+    return;
+  }
+
+  for (int i=0; i<numpages; i++)
+    markList->insertItem(QString("%1").arg(i+1), i);
+
+  _currentPage = currentpage;
+  markList->select(currentpage);
+  checkActions();
+  updateScrollBox();
+}
+
 
 void KViewPart::setPage(int page)
 {
@@ -530,7 +562,9 @@ void KViewPart::pageSelected(int nr)
 
 void KViewPart::zoomIn()
 {
-  _zoom = _zoom * 1.41;
+  _zoom = _zoom * pow(2.0, 1.0/4.0);
+  if (_zoom > 10.0)
+    _zoom = 10.0;
   _zoom = multiPage->setZoom(_zoom);
   updateScrollBox();
 }
@@ -538,7 +572,7 @@ void KViewPart::zoomIn()
 
 void KViewPart::zoomOut()
 {
-  _zoom = _zoom / 1.41;
+  _zoom = _zoom / pow(2.0, 1.0/4.0);
   if (_zoom < 0.1)
     _zoom = 0.1;
   _zoom = multiPage->setZoom(_zoom);
@@ -666,7 +700,7 @@ bool KViewPart::eventFilter(QObject *obj, QEvent *ev)
 	  QPoint delta = mousePos - newPos;
 	  multiPage->scrollView()->scrollBy(delta.x(), delta.y());
 	  mousePos = newPos;
-	}	    
+	}	
       if (ev->type() == QEvent::MouseButtonRelease)
 	multiPage->scrollView()->setCursor(Qt::arrowCursor);
     }
@@ -760,7 +794,7 @@ void KViewPart::updatePreview(bool avail)
   QPixmap pixmap(scrollBox->width(), scrollBox->height());
   QPainter p(&pixmap);
 
-  if (showPreview->isChecked() && avail 
+  if (showPreview->isChecked() && avail
       && multiPage->preview(&p, scrollBox->width(), scrollBox->height()))
     scrollBox->setBackgroundPixmap(pixmap);
   else
@@ -776,11 +810,11 @@ void KViewPart::slotPreview()
 
 void KViewPart::slotPrint()
 {
-  QStrList pages;
-  
+  QStringList pages;
+
   for (int i=0; i<markList->count(); i++)
     if (markList->isSelected(i))
-      pages.append(QString("%1").arg(i));
+      pages.append(QString::number(i));
 
   multiPage->print(pages, page());
 }
@@ -791,25 +825,26 @@ void KViewPart::readSettings()
   KConfig *config = instance()->config();
 
   config->setGroup("GUI");
-  
+
   showmarklist->setChecked(config->readBoolEntry("PageMarks", true));
   slotShowMarkList();
 
   watchAct->setChecked(config->readBoolEntry("WatchFile", true));
   showPreview->setChecked(config->readBoolEntry("ShowPreview", true));
+  _zoom = multiPage->setZoom(config->readDoubleNumEntry("Zoom", 1.0));
 }
 
 
 void KViewPart::writeSettings()
 {
   KConfig *config = instance()->config();
-  
+
   config->setGroup("GUI");
-  
+
   config->writeEntry("PageMarks", showmarklist->isChecked());
   config->writeEntry("WatchFile", watchAct->isChecked());
   config->writeEntry("ShowPreview", showPreview->isChecked());
-
+  config->writeEntry("Zoom", _zoom);
   config->sync();
 }
 
