@@ -1,6 +1,8 @@
 #include "dndlistbox.h"
 #include <qdragobject.h>
+
 #include <kurl.h>
+#include <kdebug.h>
 
 void KIFDndListBox::dragEnterEvent(QDragEnterEvent *ev)
 {
@@ -14,7 +16,7 @@ void KIFDndListBox::dropEvent(QDropEvent *ev)
     if(QUriDrag::decode(ev, fileList)){
         QStrListIterator it(fileList);
         for(;it.current(); ++it){
-            warning("In dropEvent for %s", it.current());
+            kdWarning() << "In dropEvent for " << it.current() << endl;
             KURL url(it.current());
             if(!url.isMalformed()){
                 validUrls = true;
